---
sidebar_label: pd_data_frame
title: data_structures.predefined.pd_data_frame
---

## PdDataFrame Objects

```python
class PdDataFrame(DataStructure)
```

This class serializes pandas dataframes

soil.data(df) will create a pandas dataframe automatically.

#### unserialize

```python
 | @staticmethod
 | unserialize(json_data, metadata)
```

Deprecated method. It can be removed in a few months.

